VERSION = '0.0.7'

ENDPOINT_AI = 'ai'
ENDPOINT_HH = 'hh'
COMMAND_GET_STATUS = 'getDeviceStatus'
COMMAND_GET_MODEL_DESC = 'getModelDescription'
COMMAND_GET_PROGRAM = 'getProgram'
COMMAND_GET_COMMAND = 'getCommand'

DEVICE_TYPE_UNKNOWN = 'UNKNOWN'
DEVICE_TYPE_WASHING_MACHINE = 'WASHING_MACHINE'

MODEL_MATCH_WASHING_MACHINE = 'wash'
